{% extends "gfiles/table_file_select.html" %} {% load static %} {% block sb_admin_title %}History Status{% endblock sb_admin_title %} {% block sb_admin_subheading %}{% endblock sb_admin_subheading %} {% block sb_admin_breadcrumb %} Dashboard / Galaxy Summary {% endblock sb_admin_breadcrumb %} {% block sb_admin_breadcrumb_active %} / History Status {% endblock sb_admin_breadcrumb_active %} {% block hidden_value %} {% endblock hidden_value %} {% block sb_admin_custom_js %}
{% endblock sb_admin_custom_js %} {% block header1 %}Inspect Galaxy Histories{% endblock header1 %} {% block select_items_info %}

Initial update running (results in the table below may change). This can take a while if there are > 20 histories in your Galaxy instances

{% endblock select_items_info %} {% block header2 %}Remove Selected History Items{% endblock header2 %}